#!/bin/sh
#
# Q: What does this script do, exactly ?
# A: Magic (FIXME: Documentation)
#
# 


. `dirname $0`/libptxdist.sh

usage() {
	echo 
	[ -n "$1" ] && echo -e "error: $1\n"
	echo "usage: $0 -r <rootdir>"
	echo "          [-i <ipkgdir>]"
	echo "          -p permissions"
	echo "          -e eraseblocksize"
	echo "          -o outputfile"
	echo "          [-j jffs2_extra_args]"
	echo
	echo "  -r <rootdir>          use this directory as a file source"
	echo "  -i <ipkgdir>          use this directory as a ipkg packet source"
	echo "  -p <permissions>      path to permissions file"
	echo "  -e <eraseblocksize>   erase block size of the flash chips"
	echo "  -j <jffs2_extra_args> additional arguments for mkfs.jffs2"
	echo "  -o <outputfile>       JFFS2 output file basename"
	echo "  -P <PROJECTDIRS>      PROJECTDIRS"
	echo
	exit 0
}

nflag=0
vlevel=0
ROOTDIR=
IPKGDIR=
PERMISSIONS=
ERASEBLOCKSIZE=
JFFS2EXTRA=
OUTFILE=

#
# Option parser
#
while [ $# -gt 0 ]; do
	case "$1" in 
		--help) usage ;;
		-r) ROOTDIR=`ptxd_abspath $2`;     shift 2 ;;
		-i) IPKGDIR=`ptxd_abspath $2`;     shift 2 ;;
		-p) PERMISSIONS=`ptxd_abspath $2`; shift 2 ;;
		-e) ERASEBLOCKSIZE=$2;             shift 2 ;;
		-j) JFFS2EXTRA=$2;                 shift 2 ;;
		-o) OUTFILE=`ptxd_abspath $2`;     shift 2 ;;
		-P) PROJECTDIR="`ptxd_abspath $2`";   shift 2 ;;
		*)  usage "unknown option" ;;
  	esac
done

#
# Sanity checks
#
[ -z "$ROOTDIR" ]                      && usage "error: -r for your root dir"
[ ! -f "$PERMISSIONS" ]                && usage "error: specify the permissions file with -p"
[ -z "$ERASEBLOCKSIZE" ]               && usage "error: erase block size not specified"
[ ! -x "`which mkfs.jffs2`" ]          && usage "error: you need mkfs.jffs2 in your path"
[ ! -x "`which fakeroot`" ]            && usage "error: you need fakeroot in your path"
[ -n "$IPKGDIR" ] && \
[ ! -x "`which ipkg-cl`" ]             && usage "error: you need ipkg-cl in your path"
[ -z "$OUTFILE" ]                      && usage "error: specify an output file with -o"
[ -z "$PROJECTDIR" ]                   && usage "error: specify an project directory with -P"

echo

# 
# PREPARE
# --------------------------------------------------------------------------------
#

prepare_image(){
	#
	# If we use ipkg, prepare a directory for that. For using a plain root
	# directory we just select this. 
	# FIXME: This is obviously deprecated
	#
	echo "preparing image creation ..."
	if [ -n "$IPKGDIR" ]; then 
		echo "-i specified, extracting ipkg packets"
	else
		echo "-i not specified, using files from plain root directory"
		WORKDIR=$ROOTDIR
	fi
	# 
	# Show Info
	#
	echo
	echo "ROOTDIR=$ROOTDIR"
	echo "PROJECTDIR=$PROJECTDIR"
	echo "IPKGDIR=$IPKGDIR"
	echo "PERMISSIONS=$PERMISSIONS"
	echo "ERASEBLOCKSIZE=$ERASEBLOCKSIZE"
	echo "JFFS2EXTRA=$JFFS2EXTRA"
	echo "OUTFILE=$OUTFILE"
	echo "WORKDIR=$WORKDIR"
	echo

	cd $WORKDIR
	if [ -n "$IPKGDIR" ]; then
		for archive in $IPKGDIR/*.ipk; do
			ipkg-cl -f `ptxd_abspath $ROOTDIR/etc/ipkg.conf` -force-depends -o `pwd` install $archive 1> /dev/null
		done
		echo "ipkg packages extracted"
	fi
	echo "image creation prepared."
}

# 
# CREATE
# --------------------------------------------------------------------------------
#
create_image_worker(){
	[ -n "$1" ] && CONFIGNAME="_`basename $1`"
	echo "CONFIG NAME is >$CONFIGNAME<" >&2
	# first, apply predefined permissions by using some black magic
	awk -F: "$DOPERMISSIONS" $PERMISSIONS 2>/dev/null || ptxd_bailout "could not create permissions worker"
	echo "mkfs.jffs2 -d $WORKDIR --eraseblock=$ERASEBLOCKSIZE $JFFS2EXTRA -o ${OUTFILE}${CONFIGNAME}"
}

show_warning_broken_config(){
	cat << EOF 


#########################################################################
#                                                                       #
#        B R O K E N   P A R T I T I O N   D E F I N I T I O N          #
#                                                                       #
#########################################################################
#                                                                       #
#        Warning: Your Partition Image may be incomplete                #
#                 Some IPKG Packages could not be copied                #
#                                                                       #
#########################################################################


EOF
}

#
# check for multiple partition definitions
#
SPLITCONFIGS="`find $PROJECTDIR/ -maxdepth 1 -mindepth 1 -name \"*.part*\" -a \! -path \"*~*\" -a \! -path \"*#*\" -type f`"
echo "Found these Splitconfigs: >$SPLITCONFIGS<"
if [ -n "$SPLITCONFIGS" ]; then
	WORKDIR_OLD=$WORKDIR
	IPKGDIR_OLD=$IPKGDIR 

	for configfile in $SPLITCONFIGS; do
		echo "===========> $configfile START <=============="
		WORKDIR=$WORKDIR_OLD
		IPKGDIR=$IPKGDIR_OLD
		echo "creating temporary ipkg dir"
		IPKGDIR_PART=`mktemp -d /tmp/ptxdist.IPKGDIR_PART.XXXXXX`
		WORKDIR_PART=`mktemp -d /tmp/ptxdist.WORKDIR_PART.XXXXXX`
			> tmp_ipkg_file_list
		for somefile in $IPKGDIR/*.ipk; do 
			basename $somefile | awk -F_ '{print($1)}' >> tmp_ipkg_file_list
		done 
		(cat $configfile; echo) |
			sed -e "s/^\([^#]*\).*/\1/" -e "/^$/d" |
			while read ipkgfile; do 
			case "$ipkgfile" in
				ALL)
					cp -a $IPKGDIR/*.ipk $IPKGDIR_PART/
					;;
				REMAINING)
					while read filename; do 
						grep $filename $PROJECTDIR/*.part* >/dev/null 2>&1 || \
						cp -a $IPKGDIR/${filename}_*.ipk $IPKGDIR_PART/
					done < tmp_ipkg_file_list		
					;;
				*)
					cp -a $IPKGDIR/${ipkgfile}_*.ipk $IPKGDIR_PART/ || show_warning_broken_config 
					;;
			esac
		done

		WORKDIR=$WORKDIR_PART
		IPKGDIR=$IPKGDIR_PART 
		pushd $WORKDIR
			prepare_image
			echo "creating image worker - this might take a while"
			create_image_worker $configfile | fakeroot -- 2>/dev/null
		popd
		#echo "-------> CONTENT OF FILE SYSTEMS: <----------"
		#find $IPKGDIR_PART 
		#find $WORKDIR_PART
		echo "cleaning up temporary ipkg dir"
		rm -fr $IPKGDIR_PART
		rm -fr $WORKDIR_PART
		echo "===========> $configfile STOP <=============="
	done
else
	WORKDIR=`mktemp -d /tmp/ptxdist.WORKDIR_FALLBACK.XXXXXX`
	prepare_image
	pushd $WORKDIR
	create_image_worker | fakeroot -- 
	popd
	echo "cleaning up temporary workdir"
	rm -fr $WORKDIR
fi

echo "finished:"
ls -la ${OUTFILE}*


